@@ -150,21 +150,24 @@ static int Save(SaveMeshType &m, const char * filename , bool binary =true, int
         }
         fprintf(fp,"endsolid vcg\n");
     }
+	int result = 0;
+	if (ferror(fp)) result = 2;
     fclose(fp);
-    return 0;
+	return result;
 }
 static const char *ErrorMsg(int error)
 {
-  static std::vector<std::string> stl_error_msg;
-  if(stl_error_msg.empty())
-  {
-    stl_error_msg.resize(2 );
-    stl_error_msg[0]="No errors";
-      stl_error_msg[1]="Can't open file";
-    }
+	static std::vector<std::string> stl_error_msg;
+	if (stl_error_msg.empty())
+	{
+		stl_error_msg.resize(3);
+		stl_error_msg[0] = "No errors";
+		stl_error_msg[1] = "Can't open file";
+		stl_error_msg[2] = "Output Stream error";
+	}
 
-  if(error>1 || error<0) return "Unknown error";
-  else return stl_error_msg[error].c_str();
+	if (error>2 || error<0) return "Unknown error";
+	else return stl_error_msg[error].c_str();
 };
 
 /*
